Python LALR
===========

|build-status|

.. |build-status| image:: https://github.com/bwhmather/python-lalr/actions/workflows/ci.yaml/badge.svg?branch=master
    :target: https://github.com/bwhmather/python-lalr/actions/workflows/ci.yaml
    :alt: Build Status

A pure python LALR parser generator

.. _LICENSE: ./LICENSE
